@@ -6,12 +6,15 @@
 $REP_ECOSTATION="/var/www/html/outils/ecoStations";
 my $version=`grep EOLE_VERSION /etc/eole/release | tr -d "'" | cut -d '=' -f2`;
 
-if( $version == "2.5" || $version == "2.6" || $version == "2.7" ) {
+if( $version == "2.5" || $version == "2.6" ) {
 	`/usr/share/eole/controlevnc/manage_stations.py --list-all > /usr/share/eole/controlevnc/machines.db`;
 	`sed -i 's#;#\\n#g' /usr/share/eole/controlevnc/machines.db`;
 	`sed -i 's#,#;#g' /usr/share/eole/controlevnc/machines.db`;
+	`cp /usr/share/eole/controlevnc/machines.db $REP_ECOSTATION/config/copie_machines.db`;
+}
+if( $version >= "2.7" ) {
+	`salt-run mine.get '*' all_grains --out=json > $REP_ECOSTATION/config/copie_machines.db`;
 }
 
-`cp /usr/share/eole/controlevnc/machines.db $REP_ECOSTATION/config/copie_machines.db`;
 `chown root:www-data $REP_ECOSTATION/config/copie_machines.db`;
 `chmod 770 $REP_ECOSTATION/config/copie_machines.db`;
