@@ -11,6 +11,7 @@
 """
     Config pour ecoStations
 """
+import sys
 from eolesql.db_test import db_exists, test_var
 
 def test():
@@ -24,7 +25,11 @@ def pregen_func(db_handler):
         Fonction exécutée avant la génération si le test est bon
     """
     db_handler.simple_query("CREATE DATABASE ecoStations;")
-    db_handler.simple_query("GRANT ALL PRIVILEGES ON ecoStations.* TO ecostations@localhost IDENTIFIED BY 'ecostations';")
+    if sys.version_info[0] >= 3:
+        db_handler.simple_query("CREATE USER IF NOT EXISTS 'ecostations'@'localhost';")
+        db_handler.simple_query("GRANT ALL PRIVILEGES ON ecoStations.* to 'ecostations'@'localhost';")
+    else:
+        db_handler.simple_query("GRANT ALL PRIVILEGES ON ecoStations.* TO ecostations@localhost IDENTIFIED BY 'ecostations';")
     db_handler.simple_query("FLUSH PRIVILEGES;")
 
 conf_dict = dict(filenames=[],
